from pathlib import Path
from dotenv import load_dotenv

def get_path_env(path_envs: Path, name: str) -> Path:
    return path_envs / f"{name}.env"

def __load_env_base(path_envs: Path, override: bool = True) -> None:
    path_base = get_path_env(path_envs=path_envs, name="base")
    if path_base.exists():
        load_dotenv(path_base, override=override)
    else:
        print(f"base.env dont exists into {path_envs}")

def __load_env_etc(path_envs: Path, override: bool = True) -> None:
    path_etc = get_path_env(path_envs=path_envs, name="etc")
    if path_etc.exists():
        load_dotenv(path_etc, override=override)


def load_izienv(name: str, path_envs: Path = Path(".envs"), override: bool = True) -> None:
    path_env = get_path_env(path_envs=path_envs, name=name)
    if not path_env.exists():
        raise ValueError(f"{path_env} dont exists.")
    
    # Load `base.env` if exists.
    __load_env_base(path_envs=path_envs, override=override)

    # Load `{name}.env`.
    load_dotenv(path_env, override=override)

    # Load `etc.env` if exists.
    __load_env_etc(path_envs=path_envs, override=override)



from pathlib import Path
from setuptools import find_packages, setup

setup(
    name = "izienv",
    version = "0.0.6",
    author = "Alejo Prieto Dávalos",
    author_email = "alejoprietodavalos@gmail.com",
    packages = find_packages(),
    description = "Python package to handle multiple files with environment variables.",
    long_description = Path("README.md").read_text(),
    long_description_content_type = "text/markdown",
    url = "https://pypi.org/project/izienv/",
    project_urls = {
        "Source": "https://github.com/AlejoPrietoDavalos/izienv/"
    },
    python_requires = ">=3.11",
    install_requires = [
        "python-dotenv>=1.0.1"
    ],
    include_package_data = True
)



from typing import Type, TypeVar, Callable
import os

T_BaseEnv = TypeVar("T_BaseEnv", bound="BaseEnv")

class BaseEnv:
    def __init__(self, *, name: str):
        self._name = name
    
    @property
    def name(self) -> str:
        return self._name
    
    @property
    def name_upper(self) -> str:
        return self.name.upper()

def load_env_var(*, name_pre: bool = False, raise_none_error: bool = True):
    """
    - `name_pre (bool):` Add the `upper_name` to the left of the variable. Separated by "_".
    - `raise_none_error (bool):` Raise error if the `env_var` is None when load.
    """
    def decorator(func: Callable[[Type[T_BaseEnv]], str]):
        """ Raise error if result is None."""
        def wrapper(self: Type[T_BaseEnv]) -> str:
            env_name = func(self)
            if not isinstance(env_name, str):
                raise ValueError("Expected string for `env_name`.")

            if name_pre:
                env_name = f"{self.name_upper}_{env_name}"
            
            env_var = os.getenv(env_name)
            if raise_none_error and env_var is None:
                raise ValueError(f"`{func.__name__}` for `{self.name_upper}` is None")
            return env_var
        return wrapper
    return decorator
